package com.example.hellodocker.controller;

import lombok.extern.slf4j.Slf4j;
import org.springframework.validation.BindingResult;
import org.springframework.validation.FieldError;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.util.List;
import java.util.concurrent.atomic.AtomicLong;

import static com.example.hellodocker.utils.GetIPUtils.getIpAddress;

@Slf4j
@RestController
@RequestMapping("api")
public class MainController {
    /**
     * Trace日志编号
     */
    private AtomicLong traceCode = new AtomicLong(10000);


    /**
     * @param request       本次请求的HttpServletRequest 对象
     * @param name      登录请求的参数对象
     * @param result     BindingResult 检查结果对象

     * @return ErrorWordDetectRsp 对应的json格式
     */
    @RequestMapping(value = "hi")
    public String hi(HttpServletRequest request,@RequestParam(value = "name", defaultValue = "dd") String name) {
        long code = traceCode.incrementAndGet();
        log.trace("[Terminal -> PublicCloud]|{}| detect req is {}", code, name.toString());
        String ip = getIpAddress(request);
        return "Hello from docker, Hi, "+name+", your ip is: "+ip;
    }

    /**
     * @Description: 处理参数校验错误
     * @param @param result
     * @param @return 参数
     * @return Map<String,String> 返回类型
     * @throws
     */
    private String getErrors(BindingResult result)
    {
        StringBuilder sb = new StringBuilder();
        List<FieldError> list = result.getFieldErrors();
        for (FieldError error : list)
        {
            sb.append(error.getField()).append(error.getDefaultMessage());
        }
        return sb.toString();
    }
}
